import unittest
import os
import numpy as np
from PGLW.main.boxmesh import BoxMesh


class BoxMeshTest(unittest.TestCase):
    def test_distribution(self):
        n = [65, 65, 33]
        size = [100, 100, 100]
        shift = [0, 0, 0]
        bc = [501, 501, 599, 599, 601, 601]
        dist = [None, None, [[0, 0.001, 1], [1, -1, 33]]]
        boxmesh = BoxMesh(n, size, shift, bc, dist, 16, staggered=False)
        boxmesh.run()
        boxmesh.write_dist()
        ref_xy = np.array(
            [
                0.0,
                1.5625,
                3.125,
                4.6875,
                6.25,
                7.8125,
                9.375,
                10.9375,
                12.5,
                14.0625,
                15.625,
                17.1875,
                18.75,
                20.3125,
                21.875,
                23.4375,
                25.0,
                26.5625,
                28.125,
                29.6875,
                31.25,
                32.8125,
                34.375,
                35.9375,
                37.5,
                39.0625,
                40.625,
                42.1875,
                43.75,
                45.3125,
                46.875,
                48.4375,
                50.0,
                51.5625,
                53.125,
                54.6875,
                56.25,
                57.8125,
                59.375,
                60.9375,
                62.5,
                64.0625,
                65.625,
                67.1875,
                68.75,
                70.3125,
                71.875,
                73.4375,
                75.0,
                76.5625,
                78.125,
                79.6875,
                81.25,
                82.8125,
                84.375,
                85.9375,
                87.5,
                89.0625,
                90.625,
                92.1875,
                93.75,
                95.3125,
                96.875,
                98.4375,
                100.0,
            ]
        )
        ref_z = np.array(
            [
                0.0,
                0.10977387,
                0.24166445,
                0.40008911,
                0.59033033,
                0.81869757,
                1.09271598,
                1.42134493,
                1.8152288,
                2.28698169,
                2.85150578,
                3.52634067,
                4.33203685,
                5.29254022,
                6.43556666,
                7.79293347,
                9.40080045,
                11.29975444,
                13.53465052,
                16.15410096,
                19.20948453,
                22.75333943,
                26.83701369,
                31.50748811,
                36.80337202,
                42.75020984,
                49.35542286,
                56.60342483,
                64.4516442,
                72.82829121,
                81.63264919,
                90.73839767,
                100.0,
            ]
        )
        ref = [ref_xy, ref_xy, ref_z]
        for p in range(3):
            np.testing.assert_array_almost_equal(ref[p], boxmesh.dists[p], 7)
        files = [
            "grid.x3dunf",
            "xDistribution.dat",
            "yDistribution.dat",
            "zDistribution.dat",
        ]
        for filename in files:
            os.remove(filename)


if __name__ == "__main__":
    unittest.main()
